<?php

/**
 * @version     1.0.0
 * @package     com_myplayer
 * @copyright   Copyright (C) Nordmograph 2016. All rights reserved.
 * @license     GNU General Public License version 3 ; See LICENSE.txt
 * @author      Nordmograph <contact@nordmograph.com> - http://www.nordmograph.com/extensions
 */
// No direct access
defined('_JEXEC') or die;

/**
 * track Table class
 */
class MyplayerTabletrack extends JTable
{

	/**
	 * Constructor
	 *
	 * @param JDatabase A database connector object
	 */
	public function __construct(&$db)
	{
		parent::__construct('#__myplayer_tracks', 'id', $db);
	}

	/**
	 * Overloaded bind function to pre-process the params.
	 *
	 * @param    array        Named array
	 *
	 * @return    null|string    null is operation was satisfactory, otherwise returns an error
	 * @see        JTable:bind
	 * @since      1.5
	 */
	public function bind($array, $ignore = '')
	{
		$juri = JURI::base();
		$cparams 				= JComponentHelper::getParams('com_myplayer');
		$default_maxfilesize 	= $cparams->get('default_maxfilesize');
		$profileman 			= $cparams->get('profileman','0');
		//Support for file field: file
		$user 	= JFactory::getUser();
		$app 	= JFactory::getApplication();
		$input 	= $app->input;
		$files 	= $input->files->get('jform');
		if($array['created_by']==0)
			return false;
		//$app->enqueueMessage( $files['file'] );
		if(!empty($files['file']))
		{
			//$app->enqueueMessage('ERROR');
			jimport('joomla.filesystem.file');
			$file = $files['file'];
			
			if( $default_maxfilesize>0 && $file['size'] > $default_maxfilesize )
			{
				$app->enqueueMessage(sprintf(JText::_('COM_MYPLAYER_FILESISENOTALLOWED'),($default_maxfilesize/1000000)),'warning');
				return false;	
			}
			
			//Check if the server found any error.
			$fileError = $file['error'];
			$message = '';
			if($fileError > 0 && $fileError != 4)
			{
				
				switch ($fileError)
				{
					case 1:
						$message = JText::_( 'File size exceeds allowed by the server');
						break;
					case 2:
						$message = JText::_( 'File size exceeds allowed by the html form');
						break;
					case 3:
						$message = JText::_( 'Partial upload error');
						break;
				}
				if($message != '')
				{
					JError::raiseWarning(500, $message);
					return false;
				}
			}
			else if($fileError == 4)
			{
				if(isset($array['file_hidden']))
				{
							$array['file'] = $array['file_hidden'];
				}
			}
			else
			{
				
				//Check for filetype
				$okMIMETypes = 'audio/mpeg,audio/mp3,audio/mp4,audio/mp4a-latm,audio/x-m4a';
				$validMIMEArray = explode(',', $okMIMETypes);
				$fileMime = $file['type'];
				//$app->enqueueMessage($fileMime);
				if(!in_array($fileMime, $validMIMEArray)){
					JError::raiseWarning(500, 'This filetype is not allowed');
					return false;
				}
				
				// remove previous file if updating
				$db = JFactory::getDBO();
				$q = "SELECT file FROM #__myplayer_tracks WHERE id='".$array['id']."' ";
				$db->setQuery($q);
				$filetotrash = $db->loadResult();
				if($filetotrash)
				{
					$media = 'media/com_myplayer/tracks/'.$array['created_by'].'/' . $filetotrash;
					JFile::delete(JPATH_SITE.'/'.$media);
					$db = JFactory::getDBO();
					if($profileman=='js')
					{
						$q = "DELETE FROM #__community_activities WHERE content='".$media."' ";
						$db->setQuery( $q );
						if (!$db->query()) die($db->stderr(true));
					}
				}

				//Replace any special characters in the filename
				$filename = explode('.', $file['name']);
				$filename[0] = preg_replace("/[^A-Za-z0-9]/i", "-", $filename[0]);

				// add index.html
				$empty='';
				if(!JFile::exists(JPATH_SITE.'/media/com_myplayer/tracks/'.$user->id.'/index.html'))
					JFile::write( JPATH_SITE.'/media/com_myplayer/tracks/'.$user->id.'/index.html',$empty);
				if(!JFile::exists(JPATH_SITE.'/media/com_myplayer/covers/'.$user->id.'/index.html'))
					JFile::write( JPATH_SITE.'/media/com_myplayer/covers/'.$user->id.'/index.html',$empty);
				$time = time();
				//Add Timestamp MD5 to avoid overwriting
				$filename = $time . '-' . implode('.',$filename);
				$uploadPath = JPATH_SITE . '/media/com_myplayer/tracks/'.$user->id.'/' . $filename;
				$fileTemp = $file['tmp_name'];
		
				if(!JFile::exists($uploadPath))
				{
					if (!JFile::upload($fileTemp, $uploadPath)){
						JError::raiseWarning(500, 'Error moving file');
						return false;
					}
				}
				// id3 tags for hosted files
				require JPATH_COMPONENT_SITE.'/helpers/getid3/getid3.php';
				$getID3 = new getID3;
				$ThisFileInfo = $getID3->analyze($uploadPath);
				$array['duration'] = @$ThisFileInfo['playtime_string'];
				$array["id3_genre"] = @$ThisFileInfo['tags']['id3v2']['genre'][0];
				$id3_cover = $ThisFileInfo['id3v2']['APIC'][0]['data'];
				
				$id3_artist = $ThisFileInfo['id3v2']['comments']['artist'][0];
				$id3_title = $ThisFileInfo['id3v2']['comments']['title'][0];
				if ( !$array['title'])
					$array["title"]  = $id3_title;
				if ( !$array['artist'])
					$array["artist"] = $id3_artist;

				if ( !$array['title'])
					$array["title"]  = JText::_('COM_MYPLAYER_UNTITLED');
				if ( !$array['artist'])
					$array["artist"] = JText::_('COM_MYPLAYER_UNKNOWNARTIST');	
				
				
				
				if($id3_cover)
				{
					$this->writeCover( 
					JPATH_SITE.'/media/com_myplayer/covers/'.$user->id.'/'.$ThisFileInfo['filename'].'.jpg',
					$id3_cover
					);
					$array['cover'] = $filename.'.jpg';
				}
				$array['file'] = $filename;
			}
		}
		
		$enable_locafiles 		= $cparams->get('enable_locafiles', 1);
		$enable_distantfiles 	= $cparams->get('enable_distantfiles', 1);
		if(!$enable_locafiles && !$array['file_url'] )
			return false;
		elseif(!$enable_distantfiles && !$array['file'] )
			return false;
		elseif(!$array['file'] && !$array['file_url'] )
			return false;

		$task = $input->getString('task', '');
		if(($task == 'save' || $task == 'apply') && (!JFactory::getUser()->authorise('core.edit.state','com_myplayer') && $array['state'] == 1)){
			$array['state'] = 0;
		}
		if($array['id'] == 0){
			$array['created_by'] = JFactory::getUser()->id;
			$array['created_on'] = date('Y-m-d H:i:s');
		}

		if (isset($array['params']) && is_array($array['params']))
		{
			$registry = new JRegistry();
			$registry->loadArray($array['params']);
			$array['params'] = (string) $registry;
		}

		if (isset($array['metadata']) && is_array($array['metadata']))
		{
			$registry = new JRegistry();
			$registry->loadArray($array['metadata']);
			$array['metadata'] = (string) $registry;
		}
		if (!JFactory::getUser()->authorise('core.admin', 'com_myplayer.track.' . $array['id']))
		{
			$actions         = JFactory::getACL()->getActions('com_myplayer', 'track');
			$default_actions = JFactory::getACL()->getAssetRules('com_myplayer.track.' . $array['id'])->getData();
			$array_jaccess   = array();
			foreach ($actions as $action)
			{
				$array_jaccess[$action->name] = $default_actions[$action->name];
			}
			$array['rules'] = $this->JAccessRulestoArray($array_jaccess);
		}
		//Bind the rules for ACL where supported.
		if (isset($array['rules']) && is_array($array['rules']))
		{
			$this->setRules($array['rules']);
		}
		// process activity stream
		$enable_activitystream 	= $cparams->get('enable_activitystream', 1);
		$enable_podcast 		= $cparams->get('enable_podcast', 1);
		$profileman 			= $cparams->get('profileman', '0');
		$default_privacy 		= $cparams->get('default_privacy', '0');
		if($enable_activitystream && !$array['id'] && $array['shout'] && ($array['file'] OR $array['file_url'] ))
		{
			if($array['file'])
				$track_url = $juri.'media/com_myplayer/tracks/'.$array['created_by'].'/'.$array['file'];
			elseif($array['file_url'])
				$track_url = $array['file_url'];
				
			$db 	= JFactory::getDBO();
			$q ="SELECT * FROM #__myplayer_customize 
			WHERE created_by='".$array['created_by']."' 
			AND playlist_id='0' ";
			$db->setQuery($q);
			$custom = $db->loadObject();
			$colors = '';
			$attributes ='';
			if (!empty($custom))
			{
				$opacity=1;
				$color = trim($this->get_string_between($custom->css , 'color:',';'));
				$fullcolors = trim($this->get_string_between($custom->css , 'rgba(',')'));
				$colors = explode(',',$fullcolors);
				$opacity = trim(end($colors));
				$texture = trim($this->get_string_between($custom->css , 'ground:',';'));
				if(!$fullcolors)
				{
					$colors = $color;
				}
				
				if(strpos($texture,'.png')!==false)
				{
					$texture_css = 'url('.$juri.'components/com_myplayer/assets/soundmanager/bar-ui/image/patterns/'.$texture.')';
				}
				else
					$texture_css =$texture;
				$attributes = $custom->attributes;
			}
		
		
			
			$content = '<div class="sm2-bar-ui textured full-width '.$attributes.' ">
 							<div class="bd sm2-main-controls" style="background-color: '.$colors.';">
								<div class="sm2-inline-texture" style="background:'.$texture_css.'" ></div>
  								<div class="sm2-inline-gradient"></div>
								<div class="sm2-inline-element sm2-button-element">
  									<div class="sm2-button-bd">
    									<a href="#play" class="sm2-inline-button play-pause">Play / pause</a>
   									</div>
  								</div>
  								<div class="sm2-inline-element sm2-inline-status">
						   			<div class="sm2-playlist">
										<div class="sm2-playlist-target">
											<ul class="sm2-playlist-bd">
												<li><a type="audio/mp3" href="'.$track_url.'">'.sprintf( 
													JText::_('COM_MYPLAYER_TITLEBYARTIST'),
														 $array['title'],
														  $array['artist'] 
													  );
													  
				if( $array['cover'] )
				{
					$cover_url = $juri.'media/com_myplayer/covers/'. $array['created_by'].'/'. $array['cover'];  
					$content .= '<div class="myp-trackcover-as" ><img src="'.$cover_url.'" alt="cover" width="28" height="28" /></div>';
				 }
													  
													  
									$content .= '</a></li>
											</ul>
										</div>
   									</div>
   									<div class="sm2-progress">
    									<div class="sm2-row">
    										<div class="sm2-inline-time">0:00</div>
     										<div class="sm2-progress-bd">
      											<div class="sm2-progress-track">
       												<div class="sm2-progress-bar"></div>
       												<div class="sm2-progress-ball">
														<div class="icon-overlay"></div>
													</div>
      											</div>
     										</div>
     										<div class="sm2-inline-duration">0:00</div>
    									</div>
   									</div>
  								</div>
								<div class="sm2-inline-element sm2-button-element sm2-volume">
									<div class="sm2-button-bd">
										<span class="sm2-inline-button sm2-volume-control volume-shade"></span>
										<a href="#volume" class="sm2-inline-button sm2-volume-control">volume</a>
								   </div>
								</div>
 							</div>
 							<div class="bd sm2-playlist-drawer sm2-element">
						  		<div class="sm2-inline-texture">
						   			<div class="sm2-box-shadow"></div>
						  		</div>
						  		<!-- playlist content is mirrored here -->
						  		<div class="sm2-playlist-wrapper">
									<ul class="sm2-playlist-bd">
							 			<li><a href="'.$track_url.'">'.sprintf( 
													JText::_('COM_MYPLAYER_TITLEBYARTIST'),
														 $array['title'],
														  $array['artist'] 
													  );
													  
				if( $array['cover'] )
				{
					$cover_url = $juri.'media/com_myplayer/covers/'. $array['created_by'].'/'. $array['cover'];  
					$content .= '<div class="myp-trackcover-as" ><img src="'.$cover_url.'" alt="cover" width="28" height="28" /></div>';
				 }
													  
													  
													  $content .= '</a></li>
									</ul>
    							</div>
 							</div>
						</div>';
	
		}
		return parent::bind($array, $ignore);
	}

	/**
	 * This function convert an array of JAccessRule objects into an rules array.
	 *
	 * @param type $jaccessrules an arrao of JAccessRule objects.
	 */
	private function JAccessRulestoArray($jaccessrules)
	{
		$rules = array();
		foreach ($jaccessrules as $action => $jaccess)
		{
			$actions = array();
			foreach ($jaccess->getData() as $group => $allow)
			{
				$actions[$group] = ((bool) $allow);
			}
			$rules[$action] = $actions;
		}

		return $rules;
	}

	/**
	 * Overloaded check function
	 */
	public function check()
	{

		//If there is an ordering column and this is a new row then get the next ordering value
		if (property_exists($this, 'ordering') && $this->id == 0)
		{
			$this->ordering = self::getNextOrder();
		}

		return parent::check();
	}

	/**
	 * Method to set the publishing state for a row or list of rows in the database
	 * table.  The method respects checked out rows by other users and will attempt
	 * to checkin rows that it can after adjustments are made.
	 *
	 * @param    mixed    An optional array of primary key values to update.  If not
	 *                    set the instance property value is used.
	 * @param    integer  The publishing state. eg. [0 = unpublished, 1 = published]
	 * @param    integer  The user id of the user performing the operation.
	 *
	 * @return    boolean    True on success.
	 * @since    1.0.4
	 */
	public function publish($pks = null, $state = 1, $userId = 0)
	{
		// Initialise variables.
		$k = $this->_tbl_key;

		// Sanitize input.
		JArrayHelper::toInteger($pks);
		$userId = (int) $userId;
		$state  = (int) $state;

		// If there are no primary keys set check to see if the instance key is set.
		if (empty($pks))
		{
			if ($this->$k)
			{
				$pks = array($this->$k);
			}
			// Nothing to set publishing state on, return false.
			else
			{
				$this->setError(JText::_('JLIB_DATABASE_ERROR_NO_ROWS_SELECTED'));

				return false;
			}
		}

		// Build the WHERE clause for the primary keys.
		$where = $k . '=' . implode(' OR ' . $k . '=', $pks);

		// Determine if there is checkin support for the table.
		if (!property_exists($this, 'checked_out') || !property_exists($this, 'checked_out_time'))
		{
			$checkin = '';
		}
		else
		{
			$checkin = ' AND (checked_out = 0 OR checked_out = ' . (int) $userId . ')';
		}

		// Update the publishing state for rows with the given primary keys.
		$this->_db->setQuery(
			'UPDATE `' . $this->_tbl . '`' .
			' SET `state` = ' . (int) $state .
			' WHERE (' . $where . ')' .
			$checkin
		);
		$this->_db->execute();

		// If checkin is supported and all rows were adjusted, check them in.
		if ($checkin && (count($pks) == $this->_db->getAffectedRows()))
		{
			// Checkin each row.
			foreach ($pks as $pk)
			{
				$this->checkin($pk);
			}
		}

		// If the JTable instance value is in the list of primary keys that were set, set the instance.
		if (in_array($this->$k, $pks))
		{
			$this->state = $state;
		}

		$this->setError('');

		return true;
	}

	/**
	 * Define a namespaced asset name for inclusion in the #__assets table
	 * @return string The asset name
	 *
	 * @see JTable::_getAssetName
	 */
	protected function _getAssetName()
	{
		$k = $this->_tbl_key;

		return 'com_myplayer.track.' . (int) $this->$k;
	}

	/**
	 * Returns the parent asset's id. If you have a tree structure, retrieve the parent's id using the external key field
	 *
	 * @see JTable::_getAssetParentId
	 */
	protected function _getAssetParentId(JTable $table = null, $id = null)
	{
		// We will retrieve the parent-asset from the Asset-table
		$assetParent = JTable::getInstance('Asset');
		// Default: if no asset-parent can be found we take the global asset
		$assetParentId = $assetParent->getRootId();
		// The item has the component as asset-parent
		$assetParent->loadByName('com_myplayer');
		// Return the found asset-parent-id
		if ($assetParent->id)
		{
			$assetParentId = $assetParent->id;
		}
		return $assetParentId;
	}

	public function delete($pk = null)
	{
		$playlistid = $pk[1];
		$pk = $pk[0];
		$app 	= JFactory::getApplication();
		$latest=0;
		if($playlistid=='0')
			$latest=1;
		$db = JFactory::getDBO();
		$this->load($pk);
		$result = parent::delete($pk);
		$i=0;
		if ($result)
		{
			jimport('joomla.filesystem.file');
			$media = 'media/com_myplayer/tracks/'.$this->created_by.'/' . $this->file;
			$cover = 'media/com_myplayer/covers/'.$this->created_by.'/' . $this->file.'.jpg';
			JFile::delete(JPATH_SITE .'/'. $media);
			JFile::delete(JPATH_SITE .'/'. $cover);
			$cparams 				= JComponentHelper::getParams('com_myplayer');
			$enable_activitystream 	= $cparams->get('enable_activitystream', 1);
			$profileman 			= $cparams->get('profileman', '0');
			if($enable_activitystream)		// delete related activities
			{
				if($profileman=='js')
				{
					$q = "DELETE FROM #__community_activities 
					WHERE params='{\"trackid\":\"".$this->id."\"}' 
					AND actor='".$this->created_by."'  ";
					$db->setQuery( $q );
            		$db->execute();
				}
				elseif($profileman=='es')
				{
					require_once JPATH_ROOT.'/administrator/components/com_easysocial/includes/foundry.php';
					Foundry::stream()->delete( $this->id , 'tracks', $this->created_by );
				}
			}
			$i++;
			$q = "DELETE FROM #__myplayer_tracksplaylists WHERE track_id='".$this->id."' ";
			$db->setQuery( $q );
			$db->execute();
			
			$redir_url = 'index.php?option=com_myplayer&view=tracks';
			if($latest)
				$redir_url .='&playlistid='.$playlistid.'&latest=1';
			elseif($playlistid)
				$redir_url .='&playlistid='.$playlistid;
			else $redir_url .='&no=1';
			$redir_url .='&Itemid='.$app->input->getInt('Itemid');
			
			$app->enqueueMessage(sprintf(JText::_('COM_MYPLAYER_N_ITEMS_DELETED'), $i ) );
			//$app->enqueueMessage( $this->playlist_id );
			$app->redirect( JRoute::_($redir_url, false) );
		}
		return $result;
	}
}