<?php

/**
 * @version     1.0.0
 * @package     com_myplayer
 * @copyright   Copyright (C) Nordmograph 2016. All rights reserved.
 * @license     GNU General Public License version 3 ; See LICENSE.txt
 * @author      Nordmograph <contact@nordmograph.com> - http://www.nordmograph.com/extensions
 */
defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Myplayer records.
 */
class MyplayerModelPlayer extends JModelList
{

	/**
	 * Constructor.
	 *
	 * @param    array    An optional associative array of configuration settings.
	 *
	 * @see        JController
	 * @since      1.6
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields']))
		{
			$config['filter_fields'] = array(
				                'id', 'a.id',
                'title', 'a.title',
                'artist', 'a.artist',
                'duration', 'a.duration',
                'id3_genre', 'a.id3_genre',
                'file', 'a.file',
                'file_url', 'a.file_url',
                'ordering', 'a.ordering',
                'state', 'a.state',
                'created_by', 'a.created_by',

			);
		}
		parent::__construct($config);
	}

	

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return    JDatabaseQuery
	 * @since    1.6
	 */
	protected function getListQuery()
	{
		$user	= JFactory::getUser();
		$app	= JFactory::getApplication();
		$userid = $app->input->getInt('userid');
		$playlistid = $app->input->getInt('playlistid');
		$latest = $app->input->getInt('latest');
		$format = $app->input->get('format');

		if(!$userid && $format!='feed')
			$userid = $user->id;
		
		if(!$playlistid && $format!='feed')
		{
			require_once JPATH_BASE.'/components/com_myplayer/helpers/myplayer.php' ;
			$playlistid = MyplayerFrontendHelper::getFirstPlaylist($userid );	
		}
		
		
		
			
		// Create a new query object.
		$db    = $this->getDbo();
		$query = $db->getQuery(true);

		// Select the required fields from the table.
		$query
			->select(
				$this->getState(
					'list.select', 'DISTINCT a.*'
				)
			);

		$query->from('`#__myplayer_tracks` AS a');

		
		// Join over the users for the checked out user.
		$query->select('uc.name AS editor');
		$query->join('LEFT', '#__users AS uc ON uc.id=a.checked_out');
    
		// Join over the created by field 'created_by'
		$query->join('LEFT', '#__users AS created_by ON created_by.id = a.created_by');
		
		if($playlistid && !$latest)
			$query->join('', "#__myplayer_tracksplaylists AS tp ON tp.track_id = a.id AND tp.playlist_id='".$playlistid."'  ");
		else
			$query->join('LEFT', "#__myplayer_tracksplaylists AS tp ON tp.track_id = a.id  ");
			
		$query->where('a.created_by = ' . (int) $userid );
		$query->where('a.created_by != 0'  );
		$query->where('a.state = 1');
		

		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search))
		{
			if (stripos($search, 'id:') === 0)
			{
				$query->where('a.id = ' . (int) substr($search, 3));
			}
			else
			{
				$search = $db->Quote('%' . $db->escape($search, true) . '%');
				$query->where('( a.title LIKE '.$search.'  OR  a.artist LIKE '.$search.' )');
			}
		}


		// Add the list ordering clause.
		if($latest OR !$playlistid)
			$orderCol  = 'id';
		else
			$orderCol  = 'tp.ordering';
		$orderDirn = 'DESC';
	
		if ($orderCol && $orderDirn)
		{
			$query->order($db->escape($orderCol . ' ' . $orderDirn));
		}

		return $query;
	}

	public function getItems()
	{
		$items = parent::getItems();
		return $items;
	}
}
