<?php
/**
 * @version     1.0.0
 * @package     com_myplayer
 * @copyright   Copyright (C) Nordmograph 2016. All rights reserved.
 * @license     GNU General Public License version 3 ; See LICENSE.txt
 * @author      Nordmograph <contact@nordmograph.com> - http://www.nordmograph.com/extensions
 */

// No direct access.
defined('_JEXEC') or die;

jimport('joomla.application.component.modelform');
jimport('joomla.event.dispatcher');

/**
 * Myplayer model.
 */
class MyplayerModelTrackForm extends JModelForm
{
    
    var $_item = null;
    
	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @since	1.6
	 */
	protected function populateState()
	{
		$app = JFactory::getApplication('com_myplayer');

		// Load state from the request userState on edit or from the passed variable on default
        if (JFactory::getApplication()->input->get('layout') == 'edit') {
            $id = JFactory::getApplication()->getUserState('com_myplayer.edit.track.id');
        } else {
            $id = JFactory::getApplication()->input->get('id');
            JFactory::getApplication()->setUserState('com_myplayer.edit.track.id', $id);
        }
		$this->setState('track.id', $id);

		// Load the parameters.
        $params = $app->getParams();
        $params_array = $params->toArray();
        if(isset($params_array['item_id'])){
            $this->setState('track.id', $params_array['item_id']);
        }
		$this->setState('params', $params);

	}
        

	/**
	 * Method to get an ojbect.
	 *
	 * @param	integer	The id of the object to get.
	 *
	 * @return	mixed	Object on success, false on failure.
	 */
	public function &getData($id = null)
	{
		if ($this->_item === null)
		{
			$this->_item = false;

			if (empty($id)) {
				$id = $this->getState('track.id');
			}

			// Get a level row instance.
			$table = $this->getTable();
			// Attempt to load the row.
			if ($table->load($id))
			{
                
                $user = JFactory::getUser();
                $id = $table->id;
                $canEdit = $user->authorise('core.edit', 'com_myplayer') || $user->authorise('core.create', 'com_myplayer');
                if (!$canEdit && $user->authorise('core.edit.own', 'com_myplayer')) {
                    $canEdit = $user->id == $table->created_by;
                }

                if (!$canEdit) {
                    JError::raiseError('500', JText::_('JERROR_ALERTNOAUTHOR'));
                }
                
				// Check published state.
				if ($published = $this->getState('filter.published'))
				{
					if ($table->state != $published) {
						return $this->_item;
					}
				}

				// Convert the JTable to a clean JObject.
				$properties = $table->getProperties(1);
				$this->_item = JArrayHelper::toObject($properties, 'JObject');
				
				$db=JFactory::getDBO();
				$q = "SELECT playlist_id FROM #__myplayer_tracksplaylists WHERE track_id='".$id."' ";
				$db->setQuery($q);
				$playlists = $db->loadObjectList() ;
				$lists = array();
				for($i=0;$i<count($playlists);$i++)
					$lists[] = $playlists[$i]->playlist_id;
				$this->_item->playlists = $lists ;
				
				//var_dump( $this->_item );
			} elseif ($error = $table->getError()) {
				$this->setError($error);
			}
		}
		//var_dump($this->_item);
		return $this->_item;
	}
    
	public function getTable($type = 'Track', $prefix = 'MyplayerTable', $config = array())
	{   
        $this->addTablePath(JPATH_COMPONENT_ADMINISTRATOR.'/tables');
        return JTable::getInstance($type, $prefix, $config);
	}     

    
	/**
	 * Method to check in an item.
	 *
	 * @param	integer		The id of the row to check out.
	 * @return	boolean		True on success, false on failure.
	 * @since	1.6
	 */
	public function checkin($id = null)
	{
		// Get the id.
		$id = (!empty($id)) ? $id : (int)$this->getState('track.id');

		if ($id) {
            
			// Initialise the table
			$table = $this->getTable();

			// Attempt to check the row in.
            if (method_exists($table, 'checkin')) {
                if (!$table->checkin($id)) {
                    $this->setError($table->getError());
                    return false;
                }
            }
		}

		return true;
	}

	/**
	 * Method to check out an item for editing.
	 *
	 * @param	integer		The id of the row to check out.
	 * @return	boolean		True on success, false on failure.
	 * @since	1.6
	 */
	public function checkout($id = null)
	{
		// Get the user id.
		$id = (!empty($id)) ? $id : (int)$this->getState('track.id');

		if ($id) {
            
			// Initialise the table
			$table = $this->getTable();

			// Get the current user object.
			$user = JFactory::getUser();

			// Attempt to check the row out.
            if (method_exists($table, 'checkout')) {
                if (!$table->checkout($user->get('id'), $id)) {
                    $this->setError($table->getError());
                    return false;
                }
            }
		}

		return true;
	}    
    
	/**
	 * Method to get the profile form.
	 *
	 * The base form is loaded from XML 
     * 
	 * @param	array	$data		An optional array of data for the form to interogate.
	 * @param	boolean	$loadData	True if the form is to load its own data (default case), false if not.
	 * @return	JForm	A JForm object on success, false on failure
	 * @since	1.6
	 */
	public function getForm($data = array(), $loadData = true)
	{
		// Get the form.
		$form = $this->loadForm('com_myplayer.track', 'trackform', array('control' => 'jform', 'load_data' => $loadData));
		if (empty($form)) {
			return false;
		}

		return $form;
	}

	/**
	 * Method to get the data that should be injected in the form.
	 *
	 * @return	mixed	The data for the form.
	 * @since	1.6
	 */
	protected function loadFormData()
	{
		//$data = JFactory::getApplication()->getUserState('com_myplayer.edit.track.data', array());
       // if (empty($data)) {
            $data = $this->getData();
       // }
		//var_dump($data);
        
        return $data;
	}

	/**
	 * Method to save the form data.
	 *
	 * @param	array		The form data.
	 * @return	mixed		The user id on success, false on failure.
	 * @since	1.6
	 */
	public function save($data)
	{
		
		$id = (!empty($data['id'])) ? $data['id'] : (int)$this->getState('track.id');
        $state = (!empty($data['state'])) ? 1 : 0;
        $user = JFactory::getUser();

        if($id) {
            //Check the user can edit this item
            $authorised = $user->authorise('core.edit', 'com_myplayer') || $authorised = $user->authorise('core.edit.own', 'com_myplayer');
            if($user->authorise('core.edit.state', 'com_myplayer') !== true && $state == 1){ //The user cannot edit the state of the item.
                $data['state'] = 0;
            }
        } else {
            //Check the user can create new items in this section
            $authorised = $user->authorise('core.create', 'com_myplayer');
            if($user->authorise('core.edit.state', 'com_myplayer') !== true && $state == 1){ //The user cannot edit the state of the item.
                $data['state'] = 0;
            }
        }

        if ($authorised !== true) {
            JError::raiseError(403, JText::_('JERROR_ALERTNOAUTHOR'));
            return false;
        }

		
		// process addition here instead of table track.php
		// because we need to process the query to get the insertid for joined playlists table insetion
		$app 					= JFactory::getApplication();
		$db 					= JFactory::getDBO();

		$juri 					= JURI::base();
		$cparams 				= JComponentHelper::getParams('com_myplayer');
		$default_maxfilesize 	= $cparams->get('default_maxfilesize');
		$enable_locafiles 		= $cparams->get('enable_locafiles', 1);
		$enable_distantfiles 	= $cparams->get('enable_distantfiles', 1);
		
		$enable_activitystream 	= $cparams->get('enable_activitystream', 1);
		$enable_podcast 		= $cparams->get('enable_podcast', 1);
		$profileman 			= $cparams->get('profileman', '0');
		$default_privacy 		= $cparams->get('default_privacy', '0');
		
		$input = $app->input;
		$files = $input->files->get('jform');
		if($data['created_by']==0)
			return false;
		if(!$enable_locafiles && !$data['file_url'] )
			return false;
		elseif(!$enable_distantfiles && !$data['file'] )
			return false;
		elseif(!$data['file'] && !$data['file_url'] )
			return false;	
			
		if(!empty($files['file']))
		{
			jimport('joomla.filesystem.file');
			$file = $files['file'];
			
			if( $default_maxfilesize>0 && $file['size'] > $default_maxfilesize )
			{
				$app->enqueueMessage(sprintf(JText::_('COM_MYPLAYER_FILESISENOTALLOWED'),($default_maxfilesize/1000000)),'warning');
				return false;	
			}
			
			//Check if the server found any error.
			$fileError = $file['error'];
			$message = '';
			if($fileError > 0 && $fileError != 4)
			{
				
				switch ($fileError)
				{
					case 1:
						$message = JText::_( 'File size exceeds allowed by the server');
						break;
					case 2:
						$message = JText::_( 'File size exceeds allowed by the html form');
						break;
					case 3:
						$message = JText::_( 'Partial upload error');
						break;
				}
				if($message != '')
				{
					JError::raiseWarning(500, $message);
					return false;
				}
			}
			else if($fileError == 4)
			{
				if(isset($data['file_hidden']))
				{
							$data['file'] = $data['file_hidden'];
				}
			}
			else
			{
				
				//Check for filetype
				$okMIMETypes = 'audio/mpeg,audio/mp3,audio/mp4,audio/mp4a-latm,audio/x-m4a';
				$validMIMEArray = explode(',', $okMIMETypes);
				$fileMime = $file['type'];
				//$app->enqueueMessage($fileMime);
				if(!in_array($fileMime, $validMIMEArray)){
					JError::raiseWarning(500, 'This filetype is not allowed');
					return false;
				}
				
				// remove previous file if updating
				$q = "SELECT file FROM #__myplayer_tracks WHERE id='".$data['id']."' ";
				$db->setQuery($q);
				$filetotrash = $db->loadResult();
				if($filetotrash)
				{
					$media = 'media/com_myplayer/tracks/'.$data['created_by'].'/' . $filetotrash;
					JFile::delete(JPATH_SITE.'/'.$media);
					$db = JFactory::getDBO();
					$q = "DELETE FROM #__community_activities WHERE content='".$media."' ";
					$db->setQuery( $q );
            		if (!$db->query()) die($db->stderr(true)); 
				}

				//Replace any special characters in the filename
				$filename = explode('.', $file['name']);
				$filename[0] = preg_replace("/[^A-Za-z0-9]/i", "-", $filename[0]);

				// add index.html
				$empty='';
				if(!JFile::exists(JPATH_SITE . '/media/com_myplayer/tracks/'.$user->id.'/index.html'))
					JFile::write( JPATH_SITE . '/media/com_myplayer/tracks/'.$user->id.'/index.html' ,$empty);
				if(!JFile::exists(JPATH_SITE . '/media/com_myplayer/covers/'.$user->id.'/index.html'))
					JFile::write( JPATH_SITE . '/media/com_myplayer/covers/'.$user->id.'/index.html' ,$empty);
				
				
				$time = time();
						//Add Timestamp MD5 to avoid overwriting
				//$filename = md5(time()) . '-' . implode('.',$filename);
				$filename = $time . '-' . implode('.',$filename);
				$uploadPath = JPATH_SITE . '/media/com_myplayer/tracks/'.$user->id.'/' . $filename;
				$fileTemp = $file['tmp_name'];
				
				
						
				if(!JFile::exists($uploadPath))
				{
					if (!JFile::upload($fileTemp, $uploadPath)){
						JError::raiseWarning(500, 'Error moving file');
						return false;
					}
				}
						
						
				// id3 tags for hosted files
				
				require JPATH_COMPONENT.'/helpers/getid3/getid3.php';
				$getID3 = new getID3;
				$ThisFileInfo = $getID3->analyze($uploadPath);
				$data['duration'] = @$ThisFileInfo['playtime_string'];
				$data["id3_genre"] = @$ThisFileInfo['tags']['id3v2']['genre'][0];
				$id3_cover = @$ThisFileInfo['id3v2']['APIC'][0]['data'];
				
				$id3_artist = @$ThisFileInfo['id3v2']['comments']['artist'][0];
				$id3_title = @$ThisFileInfo['id3v2']['comments']['title'][0];
				if ( !$data['title'])
					$data["title"]  = $id3_title;
				if ( !$data['artist'])
					$data["artist"] = $id3_artist;
				
				
				if ( !$data['title'])
					$data["title"]  = JText::_('COM_MYPLAYER_UNTITLED');
				if ( !$data['artist'])
					$data["artist"] = JText::_('COM_MYPLAYER_UNKNOWNARTIST');	
				
				
				
				if($id3_cover)
				{
					if($data['id'])
					{
						$this->deleteCover( $data['cover'] );
					}
						
					$this->writeCover( 
						JPATH_SITE.'/media/com_myplayer/covers/'.$user->id.'/'.$ThisFileInfo['filename'].'.jpg',
						$id3_cover
					);
					$data['cover'] = $filename.'.jpg';
				}
				$data['file'] = $filename;
			}
		}
		
		
			
		
		
		
		
		$task = $input->getString('task', '');
		if(($task == 'save' || $task == 'apply') && (!JFactory::getUser()->authorise('core.edit.state','com_myplayer') && $data['state'] == 1)){
			$data['state'] = 0;
		}
		if($data['id'] == 0){
			$data['created_by'] = JFactory::getUser()->id;
			$data['created_on'] = date('Y-m-d H:i:s');
		}

		if (isset($data['params']) && is_array($data['params']))
		{
			$registry = new JRegistry();
			$registry->loadArray($data['params']);
			$data['params'] = (string) $registry;
		}

		if (isset($data['metadata']) && is_array($data['metadata']))
		{
			$registry = new JRegistry();
			$registry->loadArray($data['metadata']);
			$data['metadata'] = (string) $registry;
		}
		if (!JFactory::getUser()->authorise('core.admin', 'com_myplayer.track.' . $data['id']))
		{
			$actions         = JFactory::getACL()->getActions('com_myplayer', 'track');
			$default_actions = JFactory::getACL()->getAssetRules('com_myplayer.track.' . $data['id'])->getData();
			$array_jaccess   = array();
			foreach ($actions as $action)
			{
				$array_jaccess[$action->name] = $default_actions[$action->name];
			}
			$data['rules'] = $this->JAccessRulestoArray($array_jaccess);
		}
		//Bind the rules for ACL where supported.
		if (isset($data['rules']) && is_array($data['rules']))
		{
			//$this->setRules($data['rules']);
		}
		
		if( $data['id'] == 0 )
		{
			// DB insertion
			$q ="INSERT INTO #__myplayer_tracks 
			(title,artist,duration,id3_genre,file,file_url,cover,ordering, state,created_by,created_on)
			VALUES (
			'".$db->escape($data['title'])."',
			'".$db->escape($data['artist'])."',
			'".$db->escape($data['duration'])."',
			'".$db->escape($data['id3_genre'])."',
			'".$db->escape($data['file'])."',
			'".$db->escape($data['file_url'])."',
			'".$data['cover']."',
			'0',
			'".$data['state']."',
			'".$data['created_by']."',
			'".$data['created_on']."')" ;
			$db->setQuery( $q );
			if (!$db->query()) die($db->stderr(true)); 
			$data_id = $db->insertid();
			//$app->enqueueMessage( count( $data['playlists'] ) );
			if(isset($data['playlists']))
			{
				for ($i=0; $i<count( $data['playlists'] ) ; $i++)
				{
					$q = "INSERT INTO #__myplayer_tracksplaylists 
					(track_id,playlist_id,ordering)
					VALUES
					('".$data_id."','".$data['playlists'][$i]."','0' )";
					$db->setQuery( $q );
					if (!$db->query()) die($db->stderr(true));
				}
			}
		}
		else // update
		{
			$q = "UPDATE #__myplayer_tracks SET 
			title = '".		$db->escape($data['title'])."' ,
			artist = '".	$db->escape($data['artist'])."' ,
			duration = '".	$db->escape($data['duration'])."' ,
			id3_genre = '".	$db->escape($data['id3_genre'])."' ,
			file = '".		$db->escape($data['file'])."' ,
			file_url = '".	$db->escape($data['file_url'])."' ";
			if( $data['cover'] )
				$q .= "	,cover = '".$db->escape($data['cover'])."' ";
			
			$q .= " WHERE id = '".$data['id']."' ";
			//$app->enqueueMessage( $q );
			$db->setQuery( $q );
			if (!$db->query()) die($db->stderr(true));
			
		
			
			$q = "SELECT playlist_id FROM #__myplayer_tracksplaylists WHERE track_id='".$data['id']."' ";
			$db-> setQuery($q);
			$lists = $db->loadObjectList();
			$listz = array();
			for($i=0;$i<count($lists);$i++)
				$listz[] = $lists[$i];
			//$app->enqueueMessage( ':::'.$data['playlists'][0] );
			
			if(isset( $data['playlists'] ))
			{
				if( $listz != $data['playlists']  )
				{
					//$app->enqueueMessage( 'Playlists arrays are different !');
					
					$q =" DELETE FROM #__myplayer_tracksplaylists WHERE track_id='".$data['id']."' ";
					$db-> setQuery($q);
					$db->execute();
					
					for ($i=0; $i<count( $data['playlists'] ) ; $i++)
					{
						$q = "INSERT INTO #__myplayer_tracksplaylists 
						(track_id,playlist_id,ordering)
						VALUES
						('".$data['id']."','".$data['playlists'][$i]."','0' )";
						$db->setQuery( $q );
						if (!$db->query()) die($db->stderr(true));
					}
				}
			}
			else
			{
				$q =" DELETE FROM #__myplayer_tracksplaylists WHERE track_id='".$data['id']."' ";
				$db-> setQuery($q);
				$db->execute();
			}
			
			
		}
		
		
		
		
		
		// process activity stream
		if($enable_activitystream && !$data['id'] && $data['shout'] && ($data['file'] OR $data['file_url'] ))
		{
			if($data['file'])
				$track_url = $juri.'media/com_myplayer/tracks/'.$data['created_by'].'/'.$data['file'];
			elseif($data['file_url'])
				$track_url = $data['file_url'];
				
			$db 	= JFactory::getDBO();
			$q ="SELECT * FROM #__myplayer_customize 
			WHERE created_by='".$data['created_by']."' 
			AND playlist_id='0' ";
			$db->setQuery($q);
			$custom = $db->loadObject();
			$colors = '';
			$attributes ='';
			if (!empty($custom))
			{
				$opacity=1;
				$color = trim($this->get_string_between($custom->css , 'color:',';'));
				$fullcolors = trim($this->get_string_between($custom->css , 'rgba(',')'));
				$colors = explode(',',$fullcolors);
				$opacity = trim(end($colors));
				$texture = trim($this->get_string_between($custom->css , 'ground:',';'));
				if(!$fullcolors)
				{
					$colors = $color;
				}
				
				if(strpos($texture,'.png')!==false)
				{
					$texture_css = 'url('.$juri.'components/com_myplayer/assets/soundmanager/bar-ui/image/patterns/'.$texture.')';
				}
				else
					$texture_css =$texture;
				$attributes = $custom->attributes;
			}
		
		
			
			$content = '<div class="sm2-bar-ui textured full-width '.$attributes.' ">
 							<div class="bd sm2-main-controls" style="background-color: '.$colors.';">
								<div class="sm2-inline-texture" style="background:'.$texture_css.'" ></div>
  								<div class="sm2-inline-gradient"></div>
								<div class="sm2-inline-element sm2-button-element">
  									<div class="sm2-button-bd">
    									<a href="#play" class="sm2-inline-button play-pause">Play / pause</a>
   									</div>
  								</div>
  								<div class="sm2-inline-element sm2-inline-status">
						   			<div class="sm2-playlist">
										<div class="sm2-playlist-target">
											<ul class="sm2-playlist-bd">
												<li><a href="'.$track_url.'">'.sprintf( 
													JText::_('COM_MYPLAYER_TITLEBYARTIST'),
														 $data['title'],
														  $data['artist'] 
													  );
													  
				if( $data['cover'] )
				{
					$cover_url = $juri.'media/com_myplayer/covers/'. $data['created_by'].'/'. $data['cover'];  
					$content .= '<div class="myp-trackcover-as" ><img src="'.$cover_url.'" alt="cover" width="28" height="28" /></div>';
				 }
													  
													  
									$content .= '</a></li>
											</ul>
										</div>
   									</div>
   									<div class="sm2-progress">
    									<div class="sm2-row">
    										<div class="sm2-inline-time">0:00</div>
     										<div class="sm2-progress-bd">
      											<div class="sm2-progress-track">
       												<div class="sm2-progress-bar"></div>
       												<div class="sm2-progress-ball">
														<div class="icon-overlay"></div>
													</div>
      											</div>
     										</div>
     										<div class="sm2-inline-duration">0:00</div>
    									</div>
   									</div>
  								</div>
								<div class="sm2-inline-element sm2-button-element sm2-volume">
									<div class="sm2-button-bd">
										<span class="sm2-inline-button sm2-volume-control volume-shade"></span>
										<a href="#volume" class="sm2-inline-button sm2-volume-control">volume</a>
								   </div>
								</div>
 							</div>
 							<div class="bd sm2-playlist-drawer sm2-element">
						  		<div class="sm2-inline-texture">
						   			<div class="sm2-box-shadow"></div>
						  		</div>
						  		<!-- playlist content is mirrored here -->
						  		<div class="sm2-playlist-wrapper">
									<ul class="sm2-playlist-bd">
							 			<li><a href="'.$track_url.'">'.sprintf( 
													JText::_('COM_MYPLAYER_TITLEBYARTIST'),
														 $data['title'],
														  $data['artist'] 
													  );
													  
				if( $data['cover'] )
				{
					$cover_url = $juri.'media/com_myplayer/covers/'. $data['created_by'].'/'. $data['cover'];  
					$content .= '<div class="myp-trackcover-as" ><img src="'.$cover_url.'" alt="cover" width="28" height="28" /></div>';
				 }
													  
				$content .= '</a></li>
									</ul>
    							</div>
 							</div>
						</div>';
						
			if(count($data['playlists'])>0 )
				{ // filter owner only playlists
					$q = "SELECT id,title FROM #__myplayer_playlists 
						WHERE privacy<40 
						AND state='1' 
						AND id IN(".join(',',$data['playlists']).") ";
					$db->setQuery($q);
					$stream_lists = $db->loadObjectList();
				}
	
			if($profileman=='js')
			{
				$jspath = JPATH_ROOT .  '/components/com_community';
				include_once $jspath.  '/libraries/core.php';
				$actor = CFactory::getUser($act->actor);
				CFactory::load('libraries', 'activities');          
				$act = new stdClass();
				$act->track_url = $track_url;
				$act->cmd    	= 'wall.write';
				$act->actor    	= $data['created_by'];
				$act->target    = 0; // no target
				$act_title    	= sprintf( JText::_('COM_MYPLAYER_TITLEBYARTIST') ,
					 $data['title'],$data['artist']) ;
				if(count($data['playlists'])>0 )
				{ // filter owner only playlists
					
					if(count($stream_lists)>0)
					{
						if($count_stream_lists<2)
							$stream->title .= ' '.JText::_('COM_MYPLAYER_TOPLAYLIST');
						else
							$stream->title .= ' '.JText::_('COM_MYPLAYER_TOPLAYLISTS');
						foreach($stream_lists as $h=>$feed_list)
						{
							$playerurl = 'index.php?option=com_community&view=profile&userid='
							.$user->id.'&playlistid='.$feed_list->id ;
							$act_title .= '<a 
							href="'.JRoute::_($playerurl).'#myplayer" >'.$feed_list->title.'</a>';	
							if($h + 1 <count($feed_lists))
							 $act_title .= ' | ';
						}
					}
				}
				$act->title			= $act_title;
				$act->content   	= $content;
				$act->app    		= 'myplayer.trackaddition';
				$act->access  		= $default_privacy;
				$act->cid    		= 0;
				$act->params		= '{"trackid":"'.$data_id.'"}';
				$act->comment_id	= CActivities::COMMENT_SELF;
				$act->comment_type	= 'myplayer.trackaddition';
				$act->like_id		= CActivities::LIKE_SELF;		
				$act->like_type		= 'myplayer.trackaddition';
				CActivityStream::add($act);
			}
			elseif($profileman=='es')
			{
				require_once JPATH_ROOT.'/administrator/components/com_easysocial/includes/foundry.php';
				$q ="SELECT id FROM #__social_apps sa
				WHERE element='myplayer' AND type='apps' AND sa.group='user' AND state='1' ";
				$db->setQuery($q);
				$app_id = $db->loadResult();
				
				
				$stream     = Foundry::stream();
				$template   = $stream->getTemplate();
				//$my         = Foundry::user();
				$template->setActor( $user->id , 'user' );
				$template->setVerb( 'add' );
				$contextParams =  array( 
					'file'=>$data['file'],
					'content'=>$content,
					'stream_lists'=>$stream_lists,
					'app_id'=>$app_id
				);
				$template->setContext( $data_id  , 'tracks' , $contextParams );
				$template->setType( 'full' );
				$streamItem = $stream->add($template);
			}
		}

		
        
	}
	// from track.php
	/**
	 * This function convert an array of JAccessRule objects into an rules array.
	 *
	 * @param type $jaccessrules an arrao of JAccessRule objects.
	 */
	private function JAccessRulestoArray($jaccessrules)
	{
		$rules = array();
		foreach ($jaccessrules as $action => $jaccess)
		{
			$actions = array();
			foreach ($jaccess->getData() as $group => $allow)
			{
				$actions[$group] = ((bool) $allow);
			}
			$rules[$action] = $actions;
		}

		return $rules;
	}
    
     function delete($data)
    {
        $id = (!empty($data['id'])) ? $data['id'] : (int)$this->getState('track.id');
        if(JFactory::getUser()->authorise('core.delete', 'com_myplayer') !== true){
            JError::raiseError(403, JText::_('JERROR_ALERTNOAUTHOR'));
            return false;
        }
		$app 	= JFactory::getApplication();
        $table = $this->getTable();
        if ($table->delete($data['id']) === true) {
            return $id;
        } else {
            return false;
        }
       
        return true;
    }
	
	function getCountTracks()
    {
        $db = JFactory::getDBO();
		$user = JFactory::getUser();
		$q ="SELECT COUNT(*)
		 FROM #__myplayer_tracks 
		 WHERE created_by='".$user->id."' ";
		$db->setQuery($q);
		$count = $db->loadResult();
        return $count;
    }
	public function get_string_between($string, $start, $end){
		$string = " ".$string;
		$ini = strpos($string,$start);
		if ($ini == 0) return "";
		$ini += strlen($start);
		$len = strpos($string,$end,$ini) - $ini;
		return substr($string,$ini,$len);
	}
	public function writeCover($filename, $filecontents)
	{ 
		$desired_side 	= 200; //px
		$src 	= imagecreatefromstring( $filecontents );
		$thumb 	= imagecreatetruecolor( $desired_side,  $desired_side );
		$x 		= imagesx($src);
		$y 		= imagesy($src);
		imagealphablending( $thumb, false);
		imagesavealpha( $thumb,true);
		$transparent = imagecolorallocatealpha($thumb, 255, 255, 255, 127);
		imagefilledrectangle($thumb, 0, 0, $desired_side, $desired_side, $transparent);
		imagecopyresampled( $thumb,  $src,  0,  0,  0,  0,  $desired_side ,  $desired_side,  $x,  $y );
		imagejpeg($thumb, $filename ,  90);
		imagedestroy($src);
	}
	public function deleteCover($filename)
	{ 
		$app = JFactory::getApplication();
		$user = JFactory::getUser();
		jimport('joomla.filesystem.file');
		JFile::delete(JPATH_SITE.'/media/com_myplayer/covers/'.$user->id.'/'.$filename);
		$app->enqueueMessage('cover deleted successf: '.JPATH_SITE.'/com_myplayer/covers/'.$user->id.'/'.$filename);
	}
    
}